ContainerConfig

Struct ContainerConfig 

pub struct ContainerConfig<'l> { /* private fields */ }
Create a new instance of the ContainerConfig struct with the given parameters.

Examples

Creating a new configuration using the derived builder:

 use docker_utils::*;

    let config = ContainerConfig::builder()
        .name("test_container")
        .image("test_image")
        .tag("latest")
        .url("0.0.0.0")
        .connection_port(8080)
        .reuse_container(true)
        .keep_configuration(true)
        .wait_strategy(WaitStrategy::NoWait)
        .build();

Implementations

Source

impl<'l> ContainerConfig<'l>

pub fn builder() -> ContainerConfigBuilder<'l>

Create an instance of ContainerConfig using the builder syntax

Source

impl<'l> ContainerConfig<'l>

pub const fn new( name: &'l str, image: &'l str, tag: &'l str, url: &'l str, connection_port: u16, additional_ports: Option<&'l [u16]>, additional_env_vars: Option<&'l [&'l str]>, platform: Option<&'l str>, reuse_container: bool, keep_configuration: bool, wait_strategy: WaitStrategy, ) -> Self

Create a new instance of the ContainerConfig struct with the given parameters.

Arguments
  • name - The name of the container.
  • image - The image to use for the container.
  • tag - The tag of the image.
  • url - The default URL of the container. Usually 0.0.0.0
  • connection_port - The port number for the main connection i.e. 80 for a webserver.
  • additional_ports - An optional array of additional ports to publish.
  • platform - An optional platform string in case the container image is not multi-arch.
  • reuse_container - A boolean flag indicating whether to reuse an existing container if found.
  • keep_configuration - A boolean flag indication whether to keep the configuration upon every environment setup. If set to true, the same configuration will be used across all environment setups. If false, each setup will re-create all tables and import data.,
  • wait_strategy - The wait strategy to use for the container.

Examples

Creating a new configuration using the constructor:

use docker_utils::*;

    let config =  ContainerConfig::new(
        "test_container",
        "test_image",
        "latest",
        "0.0.0.0",
        8080,
        Some(&[8081, 8082]),
        Some(&["ENV_VAR=VALUE", "DEBUG=true"]),
        Some("linux/amd64"),
        true,
        false,
        WaitStrategy::default(), // NoWait is the default wait strategy
    );
Returns

Returns a new instance of the ContainerConfig struct.

Source

impl<'l> ContainerConfig<'l>

pub const fn name(&self) -> &'l str

pub fn container_image(&self) -> String

pub fn container_name(&self) -> String

pub const fn url(&self) -> &'l str

pub const fn connection_port(&self) -> u16

pub const fn additional_ports(&self) -> Option<&'l [u16]>

pub const fn additional_env_vars(&self) -> Option<&'l [&'l str]>

pub const fn platform(&self) -> Option<&'l str>

pub const fn reuse_container(&self) -> bool

pub const fn keep_configuration(&self) -> bool

pub const fn wait_strategy(&self) -> &WaitStrategy

pub const fn image(&self) -> &'l str

pub const fn tag(&self) -> &'l str